var fs = require("fs"),
	path = require("path");

/**
 * scanFolder finds files matching an extension recursively
 * from a root folder.
 * @param root the root folder
 * @param endswith the file extension
 * @param recursive include full subdir tree
 * @param allow scanning special files/folders { dotfiles: false, dotfolders: false, modules: false } 
 */
module.exports = function(root, endswith, recursive, allow) {
	endswith = endswith || "*";
	allow = allow || { dotfolders: false, dotfiles: false, modules: false };
	recursive = recursive !== false;
	
	var files = [];
			
	function walk(dir) {
	    if(!fs.existsSync(dir)) {
	        return;
	    }

	    var list = fs.readdirSync(dir);
	    if (!list.length) {
	        return;
	    }
	
	    for(var i=0, len=list.length; i<len; i++) {
	        var file = list[i],
				fullpath = path.resolve(dir, file),
				stat = fs.statSync(fullpath),
				isdir = stat.isDirectory();
				
			// if it's a folder and we are scanning recursively we scan the subdir
	        if (isdir) {
			    if(!allow.modules && file == "node_modules") {
			        continue;
			    }
				if(recursive) {
	            	walk(fullpath);
				}
            	continue;
	        }
			
			var dotindex = file.indexOf("."),
				isdot = dotindex === 0;
			
			// dotfiles and folders
	        if(isdot) {
				if(!isdir && !allow.dotfiles) {
	            	continue;
				}
				else if(isdir && !allow.dotfolders) {
					continue;
				}
			}
			
			var lastmatch = file.lastIndexOf(endswith);
			if(lastmatch < 0 && endswith != "*") {
				continue;
			}

			// otherwise if it's a file and it matches
	        if(endswith == "*" || (lastmatch == file.length - endswith.length)) {
	            files.push(fullpath);
	        }
	    }
	}

    walk(root);
    return files;
};
