var assert = require("assert"),
	mocha = require("mocha"),
	path = require("path"),
	scanFolder = require(__dirname + "/../index.js");
	
describe("scanFolder", function(){
	
	var rootdir = path.resolve(__dirname, "../");
	
	describe(".js files, default settings", function(){
		it("should return 2 files", function(){
			var files = scanFolder(rootdir, ".js");
			assert.equal(2, files.length);
		});
	});
	
	describe(".config.js files, default settings", function(){
		it("should return no files", function(){
			var files = scanFolder(rootdir, ".config.js");
			assert.equal(0, files.length);
		});
	});
	
	describe(".js files, recursive, node_modules allowed", function(){
		it("should return 2+ files", function(){
			var files = scanFolder(rootdir, ".js", true, { modules: true });
			assert.equal(true, files.length >= 2);
		});
	});
	
	describe(".gitignore files, default settings", function(){
		it("should return no files", function(){
			var files = scanFolder(rootdir, ".gitignore");
			assert.equal(0, files.length);
		});
	});
		
	describe(".gitignore files, not recursive, dotfiles allowed", function(){
		it("should return 1 files", function(){
			var files = scanFolder(rootdir, ".gitignore", false, { dotfiles: true });
			assert.equal(1, files.length);
		});
	});
	
		
	describe(".gitignore files, not recursive, dotfolders allowed (but pointless)", function(){
		it("should return no files", function(){
			var files = scanFolder(rootdir, ".gitignore", false, { dotfolders: true });
			assert.equal(0, files.length);
		});
	});
	
	describe(".gitignore files, recursive, modules allowed", function(done) {
		it("should return 1+ files", function(done){
			var files = scanFolder(rootdir, "package.json", true, { dotfiles: true, modules: true });
			assert.equal(true, files.length >= 1);
			done();
		});
	});
});